@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -44,24 +44,26 @@
 #define VERSION "unknown"
 #endif
 
-int main(void)
-{ 
-  union {
-    unsigned char cc[4]; 
+int
+main (void)
+{
+  union
+  {
+    unsigned char cc[4];
     unsigned short s[2];
-    unsigned long  n;
+    unsigned long n;
   } u;
   int little_endian;
-  FILE* pf;
+  FILE *pf;
 
   u.n = 0x12345678;
-  little_endian = ( u.s[0] == 0x5678 &&  u.s[1] == 0x1234 && u.cc[0] == 0x78 &&
-		   u.cc[1] == 0x56   && u.cc[2] == 0x34   && u.cc[3] == 0x12);
-  assert ( (pf = fopen (CONFIG_H, "w")) != NULL );
+  little_endian = (u.s[0] == 0x5678 && u.s[1] == 0x1234 && u.cc[0] == 0x78 &&
+		   u.cc[1] == 0x56 && u.cc[2] == 0x34 && u.cc[3] == 0x12);
+  assert ((pf = fopen (CONFIG_H, "w")) != NULL);
 
   fprintf (pf, "#ifndef _HPACONF_H_\n#define _HPACONF_H_\n\n");
   fprintf (pf, "#define HPA_VERSION \t \"%s\"\n", VERSION);
-  if ( (little_endian) )
+  if ((little_endian))
     fprintf (pf, "#define XLITTLE_ENDIAN \t 1\n");
   else
     fprintf (pf, "#define XBIG_ENDIAN \t 1\n");
@@ -76,6 +78,6 @@ int main(void)
   fprintf (pf, "#define XERR_DFL \t 1\n\n");
 #endif
   fprintf (pf, "#endif\n");
-  assert ( fclose(pf) == 0 );
+  assert (fclose (pf) == 0);
   return 0;
 }
