@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -57,51 +57,65 @@
 #define DYN_RANGE     "     2^16384 > x > 2^(-16383)"
 #define DYN_RANGE_10  "1.19*10^4932 > x > 1.68*10^-(4932)"
 
-void library_desc (void)
+void
+library_desc (void)
 {
-  fprintf (stdout, "----- Features of the HPA library (including build options) -----\n\n");
-  fprintf (stdout, "Size of an extended precision floating point value (in bytes): %u\n",
+  fprintf (stdout,
+	   "----- Features of the HPA library (including build options) -----\n\n");
+  fprintf (stdout,
+	   "Size of an extended precision floating point value (in bytes): %u\n",
 	   XSIZE);
-  fprintf (stdout, "Number of bits available for the sign:     %u\n", SGN_NBITS);
-  fprintf (stdout, "Number of bits available for the exponent: %u\n", EXP_NBITS);
-  fprintf (stdout, "Number of bits available for the mantissa: %u\n", MNT_NBITS);
-  fprintf (stdout, "Decimal digits of accuracy:               ~%lu\n", PREC_DIGS);
-  fprintf (stdout, "Dynamic range supported:     %s      i.e.\n \t\t\t     %s\n",
+  fprintf (stdout, "Number of bits available for the sign:     %u\n",
+	   SGN_NBITS);
+  fprintf (stdout, "Number of bits available for the exponent: %u\n",
+	   EXP_NBITS);
+  fprintf (stdout, "Number of bits available for the mantissa: %u\n",
+	   MNT_NBITS);
+  fprintf (stdout, "Decimal digits of accuracy:               ~%u\n",
+	   PREC_DIGS);
+  fprintf (stdout,
+	   "Dynamic range supported:     %s      i.e.\n \t\t\t     %s\n",
 	   DYN_RANGE, DYN_RANGE_10);
   fprintf (stdout, "In case of floating point error\n");
-#ifdef XERR_IGN 
+#ifdef XERR_IGN
   fprintf (stdout, "nothing is signaled\n\n");
 #elif defined(XERR_WARN)
   fprintf (stdout, "a warning message is printed on stderr\n\n");
 #elif defined(XERR_EXIT)
-  fprintf (stdout, "the calling process is terminated through a call to exit(1)\n");
+  fprintf (stdout,
+	   "the calling process is terminated through a call to exit(1)\n");
   fprintf (stdout, "after printing a suitable message on stderr\n\n");
 #else
-  fprintf (stdout, "the global (extern) variable \'xerrno\' is suitably set\n\n");
-#endif 
-}      
+  fprintf (stdout,
+	   "the global (extern) variable \'xErrNo\' is suitably set\n\n");
+#endif
+}
 
 /* Possible options: -v, -c, -l, -n */
 
-int main (int argc, char* argv[])
+int
+main (int argc, char *argv[])
 {
   int i;
   unsigned char flag = 0;
   unsigned char v, c, l, n;
 
-  if ( argc == 1)
+  if (argc == 1)
     {
       fprintf (stderr, "*** Usage:  hpaconf [-v] [-n] or\n");
       fprintf (stderr, "***         hpaconf [-c] [-l] [-n]\n\n");
       fprintf (stderr, "*** Meaning of the options:\n");
-      fprintf (stderr, "    -v      return the current version of the HPA library\n");
-      fprintf (stderr, "    -c      return flags to compile using HPA library\n");
-      fprintf (stderr, "    -l      return flags to link  against HPA library\n");
+      fprintf (stderr,
+	       "    -v      return the current version of the HPA library\n");
+      fprintf (stderr,
+	       "    -c      return flags to compile using HPA library\n");
+      fprintf (stderr,
+	       "    -l      return flags to link  against HPA library\n");
       fprintf (stderr, "    -n      insert a newline at the end\n\n");
-      library_desc();
+      library_desc ();
       return 0;
     }
-  else if ( argc > 5 )
+  else if (argc > 5)
     {
       fprintf (stderr, "*** Usage:  hpaconf [-v] [-n] or\n");
       fprintf (stderr, "***         hpaconf [-c] [-l] [-n]\n\n");
@@ -109,9 +123,9 @@ int main (int argc, char* argv[])
     }
   else
     {
-      for (i=1; i<argc; i++)
+      for (i = 1; i < argc; i++)
 	{
-	  if ( strcmp ("-v", argv[i]) == 0 )
+	  if (strcmp ("-v", argv[i]) == 0)
 	    {
 	      if (flag != 0 && flag != 8)
 		{
@@ -122,7 +136,7 @@ int main (int argc, char* argv[])
 	      else
 		flag += 1;
 	    }
-	  else if ( strcmp ("-c", argv[i]) == 0 )
+	  else if (strcmp ("-c", argv[i]) == 0)
 	    {
 	      if ((flag % 2 == 1) || ((flag >> 1) % 2 == 1))
 		{
@@ -133,7 +147,7 @@ int main (int argc, char* argv[])
 	      else
 		flag += 2;
 	    }
-	  else if ( strcmp ("-l", argv[i]) == 0 )
+	  else if (strcmp ("-l", argv[i]) == 0)
 	    {
 	      if ((flag % 2 == 1) || ((flag >> 2) % 2 == 1))
 		{
@@ -144,7 +158,7 @@ int main (int argc, char* argv[])
 	      else
 		flag += 4;
 	    }
-	  else if ( strcmp ("-n", argv[i]) == 0 )
+	  else if (strcmp ("-n", argv[i]) == 0)
 	    {
 	      if ((flag >> 3) % 2 == 1)
 		{
@@ -161,28 +175,28 @@ int main (int argc, char* argv[])
 	      fprintf (stderr, "***         hpaconf [-c] [-l] [-n]\n\n");
 	      return 1;
 	    }
-	} /* end for */
+	}			/* end for */
       v = flag % 2;
       c = (flag >> 1) % 2;
       l = (flag >> 2) % 2;
       n = (flag >> 3) % 2;
-      if ( (v) )
+      if ((v))
 	printf (VERSION);
-      if ( (c) )
+      if ((c))
 	{
 	  printf (IPATH);
 	  putchar (' ');
 	}
-      if ( (l) )
+      if ((l))
 	{
 	  printf (LPATH);
 	  putchar (' ');
 	  printf ("-lhpa -lm");
 	}
-      if ( (n) )
-	printf("\n");
+      if ((n))
+	printf ("\n");
       else
 	fflush (stdout);
       return 0;
-    } /* end else */
-} 
+    }				/* end else */
+}
