@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -22,36 +22,36 @@
 
 #include"xpre.h"
 
-const unsigned short m_sgn=0x8000;
-const unsigned short m_exp=0x7fff;
-const short bias=16383;
+const unsigned short xM_sgn = 0x8000;
+const unsigned short xM_exp = 0x7fff;
+const short xBias = 16383;
 
-const short d_bias=15360;
-const short d_max=2047;
-const short d_lex=12;
+const short xD_bias = 15360;
+const short xD_max = 2047;
+const short xD_lex = 12;
 
-const short f_bias=16256;
-const short f_max=255;
-const short f_lex=9;
+const short xF_bias = 16256;
+const short xF_max = 255;
+const short xF_lex = 9;
 
-const short max_p= 16*XDIM;
-const short k_lin= -8*XDIM;
+const short xMax_p = 16 * XDIM;
+const short xK_lin = -8 * XDIM;
 
-const struct xpr zero= { {0x0,0x0} };
-const struct xpr one = { {0x3fff,0x8000} };
-const struct xpr two = { {0x4000,0x8000} };
-const struct xpr ten = { {0x4002,0xa000} };
-const struct xpr x_huge = { {0x7fff,0x0} };
-const struct xpr xMinf  = { {0xffff,0x0} };
+const struct xpr xZero = { {0x0, 0x0} };
+const struct xpr xOne = { {0x3fff, 0x8000} };
+const struct xpr xTwo = { {0x4000, 0x8000} };
+const struct xpr xTen = { {0x4002, 0xa000} };
+const struct xpr xPinf = { {0x7fff, 0x0} };
+const struct xpr xMinf = { {0xffff, 0x0} };
 const struct xpr xVSV = { {0x3ff2, 0x8000} };
 const struct xpr xVGV = { {0x4013, 0x8000} };
 const struct xpr xEmax = { {0x400c, 0xb16c} };
 const struct xpr xEmin = { {0xc00c, 0xb16c} };
-const struct xpr xE2min = { {0xc00c, 0xfffb} }; /* -16382.75 */
-const struct xpr xE2max = { {0x400c, 0xfffb} }; /* +16382.75 */
+const struct xpr xE2min = { {0xc00c, 0xfffb} };	/* -16382.75 */
+const struct xpr xE2max = { {0x400c, 0xfffb} };	/* +16382.75 */
 
-static struct xpr xpzero = { {0x0, 0x0} };
-static struct xpr xnzero = { {0x0, 0x0} };
+/* static struct xpr xpzero = { {0x0, 0x0} }; */
+/* static struct xpr xnzero = { {0x0, 0x0} }; */
 
 #if XDIM == 11
 #include"mp/const11.h"
@@ -70,11 +70,14 @@ static struct xpr xnzero = { {0x0, 0x0} };
 #include"mp/const07.h"
 #endif
 
-int x_sgn (struct xpr x)
+int
+x_sgn (struct xpr x)
 {
-  if ( xprcmp (&x, &xpzero) > 0 )
+  int r = xprcmp (&x, &xZero); 
+
+  if (r > 0)
     return 1;
-  else if ( xprcmp (&x, &xnzero) < 0 )
+  else if (r < 0)
     return -1;
   else
     return 0;
