@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -22,6 +22,6 @@
 
 #include"cxpre.h"
 
-const struct cxpr cx0 = { {{0x0, 0x0}}, {{0x0, 0x0}} };
-const struct cxpr cx1 = { {{0x3fff,0x8000}}, {{0x0, 0x0}} };
-const struct cxpr cxi = { {{0x0, 0x0}}, {{0x3fff,0x8000}} };
+const struct cxpr cxZero = { {{0x0, 0x0}}, {{0x0, 0x0}} };
+const struct cxpr cxOne = { {{0x3fff, 0x8000}}, {{0x0, 0x0}} };
+const struct cxpr cxIU = { {{0x0, 0x0}}, {{0x3fff, 0x8000}} };
