@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -22,32 +22,36 @@
 
 #include "xpre.h"
 
-struct xpr sfmod(struct xpr s,int *p)
-{ 
-  unsigned short *pa,*pb; short e,k;
-  
-  pa=(unsigned short *)&s; pb=pa+1;
-  e=(*pa&m_exp)-bias;
-  if( (xsigerr (e>=15, XFPOFLOW, NULL)) )
-    { 
-      *p= -1; 
-      return s;
-    } 
-  else if(e<0)
-    { 
-      *p=0; 
+struct xpr
+xsfmod (struct xpr s, int *p)
+{
+  unsigned short *pa, *pb;
+  short e, k;
+
+  pa = (unsigned short *) &s;
+  pb = pa + 1;
+  e = (*pa & xM_exp) - xBias;
+  if ((xsigerr (e >= 15, XFPOFLOW, NULL)))
+    {
+      *p = -1;
       return s;
     }
-  *p= *pb>>(15-e); 
-  lshift(++e,pb,XDIM); 
-  *pa-=e;
-  for(e=0; *pb==0 && e<max_p ;++pb,e+=16);
-  if(e==max_p) 
-    return zero;
-  for(k=0; !((*pb<<k)&m_sgn) ;++k);
-  if((k+=e)) { 
-    lshift(k,pa+1,XDIM); 
-    *pa-=k;
-  }
+  else if (e < 0)
+    {
+      *p = 0;
+      return s;
+    }
+  *p = *pb >> (15 - e);
+  xlshift (++e, pb, XDIM);
+  *pa -= e;
+  for (e = 0; *pb == 0 && e < xMax_p; ++pb, e += 16);
+  if (e == xMax_p)
+    return xZero;
+  for (k = 0; !((*pb << k) & xM_sgn); ++k);
+  if ((k += e))
+    {
+      xlshift (k, pa + 1, XDIM);
+      *pa -= k;
+    }
   return s;
 }
