@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>
 
    This file is part of the HPA Library.
@@ -20,44 +20,46 @@
    02111-1307 USA.
 */
 
-void lshift(int n,unsigned short *pm,int m)
-{ 
-  unsigned short *pa,*pc;
-  
-  pc=pm+m-1; 
-  if (n<16*m)
+void
+xlshift (int n, unsigned short *pm, int m)
+{
+  unsigned short *pa, *pc;
+
+  pc = pm + m - 1;
+  if (n < 16 * m)
     {
-      pa=pm+n/16; 
-      m=n%16; 
-      n=16-m;
-      while (pa<pc)
-	{ 
-	  *pm=(*pa++)<<m; 
-	  *pm++ |= *pa>>n;
+      pa = pm + n / 16;
+      m = n % 16;
+      n = 16 - m;
+      while (pa < pc)
+	{
+	  *pm = (*pa++) << m;
+	  *pm++ |= *pa >> n;
 	}
-      *pm++ = *pa<<m; 
+      *pm++ = *pa << m;
     }
-  while(pm<=pc) 
-    *pm++ =0;
+  while (pm <= pc)
+    *pm++ = 0;
 }
 
-void rshift(int n,unsigned short *pm,int m)
-{ 
-  unsigned short *pa,*pc;
-  
-  pc=pm+m-1;
-  if(n<16*m)
-    { 
-      pa=pc-n/16; 
-      m=n%16; 
-      n=16-m;
-      while (pa>pm)
-	{ 
-	  *pc=(*pa--)>>m; 
-	  *pc-- |= *pa<<n;
+void
+xrshift (int n, unsigned short *pm, int m)
+{
+  unsigned short *pa, *pc;
+
+  pc = pm + m - 1;
+  if (n < 16 * m)
+    {
+      pa = pc - n / 16;
+      m = n % 16;
+      n = 16 - m;
+      while (pa > pm)
+	{
+	  *pc = (*pa--) >> m;
+	  *pc-- |= *pa << n;
 	}
-      *pc-- = *pa>>m;
+      *pc-- = *pa >> m;
     }
-  while(pc>=pm) 
-    *pc-- =0;
+  while (pc >= pm)
+    *pc-- = 0;
 }
