@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -22,19 +22,26 @@
 
 #include "xpre.h"
 
-struct xpr xdiv(struct xpr s,struct xpr t)
-{ 
+struct xpr
+xdiv (struct xpr s, struct xpr t)
+{
   struct xpr a;
-  unsigned short *pc,e,i;
-  
-  pc=(unsigned short *)&t; e= *pc; *pc=bias;
-  if ( (xsigerr (xprcmp(&t, &zero) == 0, XEDIV, "xdiv()")) )
-    return zero;
+  unsigned short *pc, e, i;
+
+  pc = (unsigned short *) &t;
+  e = *pc;
+  *pc = xBias;
+  if ((xsigerr (xprcmp (&t, &xZero) == 0, XEDIV, "xdiv()")))
+    return xZero;
   else
     {
-      a=dbltox(1/xtodbl(t)); *pc=e;
-      pc=(unsigned short *)&a; *pc+=bias-(e&m_exp); *pc|=e&m_sgn;
-      for(i=0; i<itt_div ;++i) a=xmul(a,xadd(two,xmul(a,t),1));
-      return xmul(s,a);
+      a = dbltox (1 / xtodbl (t));
+      *pc = e;
+      pc = (unsigned short *) &a;
+      *pc += xBias - (e & xM_exp);
+      *pc |= e & xM_sgn;
+      for (i = 0; i < xItt_div; ++i)
+	a = xmul (a, xadd (xTwo, xmul (a, t), 1));
+      return xmul (s, a);
     }
 }
