@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -22,14 +22,19 @@
 
 #include "xpre.h"
 
-struct xpr xevtch(struct xpr z,struct xpr *a,int m)
-{ 
-  struct xpr *p,f,t,tp,w;
-  
-  w=xpr2(z,1); t=zero; tp=zero;
-  for(p=a+m; p>a ;){
-    f=xadd(*p--,xadd(xmul(w,t),tp,1),0);
-    tp=t; t=f;
-   }
-  return xadd(*p,xadd(xmul(z,t),tp,1),0);
+struct xpr
+xevtch (struct xpr z, struct xpr *a, int m)
+{
+  struct xpr *p, f, t, tp, w;
+
+  w = xpr2 (z, 1);
+  t = xZero;
+  tp = xZero;
+  for (p = a + m; p > a;)
+    {
+      f = xadd (*p--, xadd (xmul (w, t), tp, 1), 0);
+      tp = t;
+      t = f;
+    }
+  return xadd (*p, xadd (xmul (z, t), tp, 1), 0);
 }
