@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -26,23 +26,24 @@
   Heavily modified by Ivano Primi - 01/30/2005
 */
 
-struct xpr xfmod(struct xpr s, struct xpr t, struct xpr* q)
+struct xpr
+xfmod (struct xpr s, struct xpr t, struct xpr *q)
 {
-  if ( (xsigerr (xprcmp(&t, &zero) == 0, XEDIV, "xfmod()")) )
-    return zero;
+  if ((xsigerr (xprcmp (&t, &xZero) == 0, XEDIV, "xfmod()")))
+    return xZero;
   else
     {
       unsigned short *p, mask = 0xffff;
       short e, i;
       int u;
 
-      *q = xdiv(s,t);
-      p = (unsigned short*) q;
-      u = (*p & m_sgn) ? 0 : 1;
-      e = (*p &= m_exp); /* biased exponent of *q */
-      e = e < bias ? 0 : e - bias + 1;
-      for (i=1; e / 16 > 0; i++, e -= 16);
-      if ( i <= XDIM )
+      *q = xdiv (s, t);
+      p = (unsigned short *) q;
+      u = (*p & xM_sgn) ? 0 : 1;
+      e = (*p &= xM_exp);	/* biased exponent of *q */
+      e = e < xBias ? 0 : e - xBias + 1;
+      for (i = 1; e / 16 > 0; i++, e -= 16);
+      if (i <= XDIM)
 	{
 	  /* e = 0, ..., 15 */
 	  mask <<= 16 - e;
@@ -50,14 +51,18 @@ struct xpr xfmod(struct xpr s, struct xpr t, struct xpr* q)
 	  for (i++; i <= XDIM; p[i] = 0, i++);
 	}
       /* Now *q == abs(quotient of (s/t)) */
-      return xadd(s, xmul(t,*q), u);
-    } 
+      return xadd (s, xmul (t, *q), u);
+    }
 }
 
-struct xpr xfrex(struct xpr s,int *p)
-{ 
-  unsigned short *ps=(unsigned short *)&s,u;
-  
-  *p=(*ps&m_exp)-bias+1; u= *ps&m_sgn;
-  *ps=bias-1; *ps|=u; return s;
+struct xpr
+xfrexp (struct xpr s, int *p)
+{
+  unsigned short *ps = (unsigned short *) &s, u;
+
+  *p = (*ps & xM_exp) - xBias + 1;
+  u = *ps & xM_sgn;
+  *ps = xBias - 1;
+  *ps |= u;
+  return s;
 }
