@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -34,13 +34,14 @@
   Warning: 'skip' must be positive !
 */
 
-static void nullify (int skip, unsigned short *p, int k)
+static void
+nullify (int skip, unsigned short *p, int k)
 {
   int i;
   unsigned short mask = 0xffff;
 
-  for (i=0; skip / 16 > 0; i++, skip -= 16);
-  if ( i < k )
+  for (i = 0; skip / 16 > 0; i++, skip -= 16);
+  if (i < k)
     {
       /* skip = 0, ..., 15 */
       mask <<= 16 - skip;
@@ -49,48 +50,50 @@ static void nullify (int skip, unsigned short *p, int k)
     }
 }
 
-static void canonic_form (struct xpr* px)
+static void
+canonic_form (struct xpr *px)
 {
   unsigned short *p, u;
   short e, i, j, skip;
 
-  p = (unsigned short*) px;
-  e = (*p & m_exp); /* biased exponent of x */
-  u = (*p & m_sgn); /* sign of x            */
-  if ( e < bias - 1 )
+  p = (unsigned short *) px;
+  e = (*p & xM_exp);		/* biased exponent of x */
+  u = (*p & xM_sgn);		/* sign of x            */
+  if (e < xBias - 1)
     return;
   else
     {
       unsigned short mask = 0xffff;
 
-      /* e >= bias - 1 */
-      for (i=1, skip = e+1-bias; skip / 16 > 0; i++, skip -= 16);
-      if ( i <= XDIM )
+      /* e >= xBias - 1 */
+      for (i = 1, skip = e + 1 - xBias; skip / 16 > 0; i++, skip -= 16);
+      if (i <= XDIM)
 	{
 	  /* skip = 0, ..., 15 */
 	  mask >>= skip;
-	  if ( (p[i] & mask) != mask )
+	  if ((p[i] & mask) != mask)
 	    return;
 	  else
 	    {
-	      for (j = i+1; j <= XDIM && p[j] == 0xffff; j++);
-	      if ( j > XDIM  )
+	      for (j = i + 1; j <= XDIM && p[j] == 0xffff; j++);
+	      if (j > XDIM)
 		{
 		  p[i] -= mask;
-		  for (j = i+1; j <= XDIM; p[j] = 0, j++);
-		  if ( !(p[1] & 0x8000) )
+		  for (j = i + 1; j <= XDIM; p[j] = 0, j++);
+		  if (!(p[1] & 0x8000))
 		    {
 		      p[1] = 0x8000;
-		      *p = ++e; *p |= u;
+		      *p = ++e;
+		      *p |= u;
 		    }
-		  else if ( (u) )
-		    *px = xadd (*px, one, 1);
-		  else 
-		    *px = xadd (*px, one, 0);
+		  else if ((u))
+		    *px = xadd (*px, xOne, 1);
+		  else
+		    *px = xadd (*px, xOne, 0);
 		}
 	    }
-	} /* end   if(i <= XDIM ) */
-    } /* end outer else */
+	}			/* end   if(i <= XDIM ) */
+    }				/* end outer else */
 }
 
 /*
@@ -98,33 +101,35 @@ static void canonic_form (struct xpr* px)
   xfrac(x) has the same sign as x.
 */
 
-struct xpr xfrac (struct xpr x)
+struct xpr
+xfrac (struct xpr x)
 {
   unsigned short u, *p;
   short e;
   int n;
 
   canonic_form (&x);
-  p = (unsigned short*) &x;
-  e = (*p & m_exp); /* biased exponent of x */
-  if (e < bias)
-    return x; /* The integer part of x is zero */
+  p = (unsigned short *) &x;
+  e = (*p & xM_exp);		/* biased exponent of x */
+  if (e < xBias)
+    return x;			/* The integer part of x is zero */
   else
     {
-      u = *p & m_sgn;   /* sign of x */
-      n = e - bias + 1;
-      lshift (n, p+1, XDIM);
-      e = bias - 1;
+      u = *p & xM_sgn;		/* sign of x */
+      n = e - xBias + 1;
+      xlshift (n, p + 1, XDIM);
+      e = xBias - 1;
       /* Now I have to take in account the rule */
       /* of the leading one.                    */
-      while ( e > 0 && !(p[1] & m_sgn) )
+      while (e > 0 && !(p[1] & xM_sgn))
 	{
-	  lshift (1, p+1, XDIM);
+	  xlshift (1, p + 1, XDIM);
 	  e -= 1;
 	}
       /* Now p+1 points to the fractionary part of x, */
       /* u is its sign, e is its biased exponent.     */
-      p[0] = e; p[0] |= u;
+      p[0] = e;
+      p[0] |= u;
       return *(struct xpr *) p;
     }
 }
@@ -135,19 +140,20 @@ struct xpr xfrac (struct xpr x)
   xtrunc(x) has the same sign as x.
 */
 
-struct xpr xtrunc (struct xpr x)
+struct xpr
+xtrunc (struct xpr x)
 {
   unsigned short *p;
   short e;
 
   canonic_form (&x);
-  p = (unsigned short*) &x;
-  e = (*p & m_exp); /* biased exponent of x */
-  if (e < bias)
-    return zero; /* The integer part of x is zero */
+  p = (unsigned short *) &x;
+  e = (*p & xM_exp);		/* biased exponent of x */
+  if (e < xBias)
+    return xZero;		/* The integer part of x is zero */
   else
     {
-      nullify (e - bias + 1, p+1, XDIM);
+      nullify (e - xBias + 1, p + 1, XDIM);
       return *(struct xpr *) p;
     }
 }
@@ -155,45 +161,64 @@ struct xpr xtrunc (struct xpr x)
 struct xpr
 xround (struct xpr x)
 {
-  unsigned short* ps = (unsigned short*) &x;
-
-  if ( (*ps & m_sgn) )
-    return xtrunc ( xadd(x, xrndcorr, 1) );
-  else
-    return xtrunc ( xadd(x, xrndcorr, 0) );
+  return xtrunc (xadd (x, xRndcorr, x.nmm[0] & xM_sgn));
 }
 
 struct xpr
 xceil (struct xpr x)
 {
-  unsigned short* ps = (unsigned short*) &x;
+  unsigned short *ps = (unsigned short *) &x;
 
-  if ( (*ps & m_sgn) )
+  if ((*ps & xM_sgn))
     return xtrunc (x);
   else
     {
       struct xpr y = xfrac (x);
       /* y has the same sign as x (see above). */
 
-      return ( xprcmp (&y, &zero) > 0 ? 
-	       xadd (xtrunc(x), one, 0) : x );
+      return (xprcmp (&y, &xZero) > 0 ? xadd (xtrunc (x), xOne, 0) : x);
     }
 }
 
 struct xpr
 xfloor (struct xpr x)
 {
-  unsigned short* ps = (unsigned short*) &x;
+  unsigned short *ps = (unsigned short *) &x;
 
-  if ( (*ps & m_sgn) )
+  if ((*ps & xM_sgn))
     {
       struct xpr y = xfrac (x);
       /* y has the same sign as x (see above). */
 
-      return ( xprcmp (&y, &zero) < 0 ? 
-	       xadd (xtrunc(x), one, 1) : x );
+      return (xprcmp (&y, &xZero) < 0 ? xadd (xtrunc (x), xOne, 1) : x);
     }
   else
     return xtrunc (x);
 }
 
+static void
+xadd_correction (struct xpr* px, int k)
+{
+  short e = (px->nmm[0] & xM_exp) - xBias;
+
+/*   e = (e > 0 ? e : 0);   */
+  *px = xadd (*px, xpr2 (xFixcorr, e), k);
+}
+
+struct xpr 
+xfix (struct xpr x)
+{
+  unsigned short *p;
+  short e;
+
+  xadd_correction (&x, x.nmm[0] & xM_sgn);
+  p = (unsigned short *) &x;
+  e = (*p & xM_exp);		/* biased exponent of x */
+  if (e < xBias)
+    return xZero;		/* The integer part of x is zero */
+  else
+    {
+      nullify (e - xBias + 1, p + 1, XDIM);
+      return *(struct xpr *) p;
+    }  
+}
