@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -22,30 +22,36 @@
 
 #include "xpre.h"
 
-struct xpr xneg(struct xpr s)
-{ 
-  unsigned short *p=(unsigned short *)&s;
-  
-  *p^=m_sgn; return s;
+struct xpr
+xneg (struct xpr s)
+{
+  unsigned short *p = (unsigned short *) &s;
+
+  *p ^= xM_sgn;
+  return s;
 }
 
-struct xpr xabs(struct xpr s)
-{ 
-  unsigned short *p=(unsigned short *)&s;
-  
-  *p&=m_exp; return s;
+struct xpr
+xabs (struct xpr s)
+{
+  unsigned short *p = (unsigned short *) &s;
+
+  *p &= xM_exp;
+  return s;
 }
 
-int xex(struct xpr *ps)
-{ 
-  unsigned short *q=(unsigned short *)ps;
-  
-  return (*q&m_exp)-bias;
+int
+x_exp (struct xpr *ps)
+{
+  unsigned short *q = (unsigned short *) ps;
+
+  return (*q & xM_exp) - xBias;
 }
 
-int neg(struct xpr *ps)
-{ 
-  unsigned short *q=(unsigned short *)ps;
-  
-  return (*q&m_sgn);
+int
+x_neg (struct xpr *ps)
+{
+  unsigned short *q = (unsigned short *) ps;
+
+  return (*q & xM_sgn);
 }
