@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -24,22 +24,31 @@
 #include <stdio.h>
 #include <math.h>
 
-struct xpr xsqrt(struct xpr z)
-{ 
-  struct xpr s,h; short m,e; unsigned short *pc;
-  
-  if ( (xsigerr((neg(&z)), XEDOM, "xsqrt()"))  )
-    return zero;
+struct xpr
+xsqrt (struct xpr z)
+{
+  struct xpr s, h;
+  short m, e;
+  unsigned short *pc;
+
+  if ((xsigerr ((x_neg (&z)), XEDOM, "xsqrt()")))
+    return xZero;
   else
     {
-      pc=(unsigned short *)&z;
-      if(*pc==0) return zero;
-      e= *pc-bias; *pc=bias+(e%2); e/=2;
-      s=dbltox(sqrt(xtodbl(z)));
-      for(m=0; m<itt_div ;++m){
-	h=xdiv(xadd(z,xmul(s,s),1),xpr2(s,1));
-	s=xadd(s,h,0); }
-      pc=(unsigned short *)&s; *pc+=e;
+      pc = (unsigned short *) &z;
+      if (*pc == 0)
+	return xZero;
+      e = *pc - xBias;
+      *pc = xBias + (e % 2);
+      e /= 2;
+      s = dbltox (sqrt (xtodbl (z)));
+      for (m = 0; m < xItt_div; ++m)
+	{
+	  h = xdiv (xadd (z, xmul (s, s), 1), xpr2 (s, 1));
+	  s = xadd (s, h, 0);
+	}
+      pc = (unsigned short *) &s;
+      *pc += e;
       return s;
     }
 }
