@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -21,7 +21,7 @@
 */
 
 #include <stdlib.h>
-#include <math.h>
+#include <float.h>
 #include "xpre.h"
 
 /*
@@ -51,63 +51,75 @@
 
 */
 
-float xtoflt (struct xpr s)
+float
+xtoflt (struct xpr s)
 {
   unsigned short pe[2], *pc, u;
   short i, e;
 
-  pc = (unsigned short*) &s;
-  u= *pc&m_sgn; e=(*pc&m_exp)-f_bias;
+  pc = (unsigned short *) &s;
+  u = *pc & xM_sgn;
+  e = (*pc & xM_exp) - xF_bias;
   /*
-    u is the sign of the number s.
-    e == (exponent of s) + 127 
-  */
-  if (e >= f_max) return HUGE_VAL; 
-  if (e<=0) return 0.;
-  for(i=0; i<2; pe[i]= *++pc, i++); 
-  
+     u is the sign of the number s.
+     e == (exponent of s) + 127 
+   */
+  if (e >= xF_max)
+    return (!u ? FLT_MAX : -FLT_MAX);
+  if (e <= 0)
+    return 0.;
+  for (i = 0; i < 2; pe[i] = *++pc, i++);
+
   /* In the IEEE 754 Standard the leading 1 */
   /* is not represented.                    */
-  pe[0]&=m_exp; 
+  pe[0] &= xM_exp;
   /* Now in pe[0],pe[1] we have 31 bits of mantissa. */
   /* But only the first 23 ones must be put in the   */
   /* final float number.                             */
-  rshift(f_lex-1,pe,2);
+  xrshift (xF_lex - 1, pe, 2);
   /* We have just loaded the mantissa and now we */
   /* are going to load exponent and sign.        */
-  pe[0]|=(e<<(16-f_lex)); pe[0]|=u;
+  pe[0] |= (e << (16 - xF_lex));
+  pe[0] |= u;
 #ifdef XLITTLE_ENDIAN
-  u = pe[0]; pe[0] = pe[1]; pe[1] = u;
+  u = pe[0];
+  pe[0] = pe[1];
+  pe[1] = u;
 #endif
-  return *(float *)pe;
+  return *(float *) pe;
 }
 
-struct xpr flttox (float y)
+struct xpr
+flttox (float y)
 {
-  unsigned short pe[XDIM+1],*pc,u; short i,e;
+  unsigned short pe[XDIM + 1], *pc, u;
+  short i, e;
 
-  pc=(unsigned short *)&y;
+  pc = (unsigned short *) &y;
 #ifdef XLITTLE_ENDIAN
-  pc+=1;
+  pc += 1;
 #endif
-  u= *pc&m_sgn; 
-  e= f_bias+((*pc&m_exp)>>(16-f_lex));
+  u = *pc & xM_sgn;
+  e = xF_bias + ((*pc & xM_exp) >> (16 - xF_lex));
   /*
-    Now u is the sign of y and e is the
-    biased exponent (exponent + bias).
-  */
+     Now u is the sign of y and e is the
+     biased exponent (exponent + bias).
+   */
 #ifdef XLITTLE_ENDIAN
-  for(i=1; i<3 ; pe[i]= *pc--, i++); 
+  for (i = 1; i < 3; pe[i] = *pc--, i++);
 #else
-  for(i=1; i<3 ; pe[i]= *pc++, i++);
-#endif  
-  while(i<=XDIM) 
-    pe[i++]=0;
-  pc=pe+1; lshift(f_lex-1,pc,2); *pc|=m_sgn;
+  for (i = 1; i < 3; pe[i] = *pc++, i++);
+#endif
+  while (i <= XDIM)
+    pe[i++] = 0;
+  pc = pe + 1;
+  xlshift (xF_lex - 1, pc, 2);
+  *pc |= xM_sgn;
   /* We have just put in pe[1],pe[2] the whole */
   /* mantissa of y with a leading 1.           */
   /* Now we have only to put exponent and sign */
   /* in pe[0].                                 */
-  *pe=e; *pe|=u;
-  return *(struct xpr *)pe;
+  *pe = e;
+  *pe |= u;
+  return *(struct xpr *) pe;
 }
