@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -21,47 +21,51 @@
 */
 
 /*
-    Test:  bxprint  xprint
+    Test:  xbprint  xprint
 
-    Uses:  bxprint  xprint  atox  
+    Uses:  xbprint  xprint  atox  
 
     Input file:  data/bxprint.dat
 */
 #include<stdio.h>
 #include "xpre.h"
 
-#define BUFF_SIZE 5120 /* 5 Kb */
+#define BUFF_SIZE 5120		/* 5 Kb */
 
-int main(int na,char **av)
+int
+main (int na, char **av)
 {
   int i;
   char buffer[BUFF_SIZE];
   struct xpr f;
   FILE *fp;
 
-  if(na!=2)
-    { 
-      printf("para: input_file\n");
-      exit(-1);
-    }
-  fp=fopen(*++av,"r");
-  printf("     Test of Binary Printing Functions");
-  while( fgets(buffer, BUFF_SIZE, fp) != NULL )
+  if (na != 2)
     {
-      for (i=0; buffer[i] != '\0'; i++);
-      if ( i>0 && buffer[i-1] == '\n' )
-	buffer[i-1] = '\0';
-      printf("\n string in : %s\n", buffer);
+      printf ("para: input_file\n");
+      exit (-1);
+    }
+  fp = fopen (*++av, "r");
+  printf ("     Test of Binary Printing Functions");
+  while (fgets (buffer, BUFF_SIZE, fp) != NULL)
+    {
+      for (i = 0; buffer[i] != '\0'; i++);
+      if (i > 0 && buffer[i - 1] == '\n')
+	buffer[i - 1] = '\0';
+      printf ("\n string in : %s\n", buffer);
 
       /* convert ascii string to extended precision */
       f = atox (buffer);
       /* Binary and Hexadecimal representations     */
-      printf(" binary =  "); bxprint(stdout, f); putchar('\n');
-      printf(" hex    =  "); xprint(stdout, f);
+      printf (" binary =  ");
+      xbprint (stdout, f);
+      printf (" hex    =  ");
+      xprint (stdout, f);
     }
   fclose (fp);
   return 0;
 }
+
 /*  Test output
 
      Test of Binary Printing Functions
