@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -23,178 +23,180 @@
 #include<stdio.h>
 #include"xpre.h"
 
-void canonic_form (struct xpr* px)
+void
+canonic_form (struct xpr *px)
 {
   unsigned short *p, u;
   short e, i, j, skip;
 
-  p = (unsigned short*) px;
-  e = (*p & m_exp); /* biased exponent of x */
-  u = (*p & m_sgn); /* sign of x            */
-  if ( e < bias - 1 )
+  p = (unsigned short *) px;
+  e = (*p & xM_exp);		/* biased exponent of x */
+  u = (*p & xM_sgn);		/* sign of x            */
+  if (e < xBias - 1)
     return;
   else
     {
       unsigned short mask = 0xffff;
 
-      /* e >= bias - 1 */
-      for (i=1, skip = e+1-bias; skip / 16 > 0; i++, skip -= 16);
-      if ( i <= XDIM )
+      /* e >= xBias - 1 */
+      for (i = 1, skip = e + 1 - xBias; skip / 16 > 0; i++, skip -= 16);
+      if (i <= XDIM)
 	{
 	  /* skip = 0, ..., 15 */
 	  mask >>= skip;
-	  if ( (p[i] & mask) != mask )
+	  if ((p[i] & mask) != mask)
 	    return;
 	  else
 	    {
-	      for (j = i+1; j <= XDIM && p[j] == 0xffff; j++);
-	      if ( j > XDIM  )
+	      for (j = i + 1; j <= XDIM && p[j] == 0xffff; j++);
+	      if (j > XDIM)
 		{
 		  p[i] -= mask;
-		  for (j = i+1; j <= XDIM; p[j] = 0, j++);
-		  if ( !(p[1] & 0x8000) )
+		  for (j = i + 1; j <= XDIM; p[j] = 0, j++);
+		  if (!(p[1] & 0x8000))
 		    {
 		      p[1] = 0x8000;
-		      *p = ++e; *p |= u;
+		      *p = ++e;
+		      *p |= u;
 		    }
-		  else if ( (u) )
-		    *px = xadd (*px, one, 1);
-		  else 
-		    *px = xadd (*px, one, 0);
+		  else if ((u))
+		    *px = xadd (*px, xOne, 1);
+		  else
+		    *px = xadd (*px, xOne, 0);
 		}
 	    }
-	} /* end   if(i <= XDIM ) */
-    } /* end outer else */
+	}			/* end   if(i <= XDIM ) */
+    }				/* end outer else */
 }
 
-int main (void)
+int
+main (void)
 {
-  struct xpr six = { 
-    0x4001, 0xbfff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
-  struct xpr seven = { 
-    0x4001, 0xdfff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
-  struct xpr eight = { 
-    0x4001, 0xffff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
+  struct xpr six = {
+    0x4001, 0xbfff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
+  };
+  struct xpr seven = {
+    0x4001, 0xdfff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
+  };
+  struct xpr eight = {
+    0x4001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
+  };
+  struct xpr one_two_seven = {
+    0x4005, 0xfdff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
   };
-  struct xpr one_two_seven = { 
-    0x4005, 0xfdff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
 
-  struct xpr msix = { 
-    0xc001, 0xbfff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
-  struct xpr mseven = { 
-    0xc001, 0xdfff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
-  struct xpr meight = { 
-    0xc001, 0xffff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
-  struct xpr mone_two_seven = { 
-    0xc005, 0xfdff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
+  struct xpr msix = {
+    0xc001, 0xbfff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
+  };
+  struct xpr mseven = {
+    0xc001, 0xdfff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
+  };
+  struct xpr meight = {
+    0xc001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
+  };
+  struct xpr mone_two_seven = {
+    0xc005, 0xfdff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
   };
 
   struct xpr one_half = {
-    0x3ffd, 0xffff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
+    0x3ffd, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
   };
   struct xpr _1_ = {
-    0x3ffe, 0xffff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
-  }; 
-  struct xpr almost_seven = { 
-    0x4001, 0xdfff, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xfffe 
+    0x3ffe, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
   };
-  struct xpr near_seven = { 
-    0x4001, 0xdffe, 0xffff, 0xffff, 0xffff , 0xffff , 0xffff, 0xffff 
+  struct xpr almost_seven = {
+    0x4001, 0xdfff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xfffe
+  };
+  struct xpr near_seven = {
+    0x4001, 0xdffe, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
   };
 
-  struct xpr Zero = zero;
-  struct xpr One  = one;
+  struct xpr Zero = xZero;
+  struct xpr One = xOne;
 
   printf ("\nsix=\n");
-  bxprint (stdout, six);
+  xbprint (stdout, six);
   canonic_form (&six);
-  printf ("\nsix=\n");
-  bxprint (stdout, six);
+  printf ("six=\n");
+  xbprint (stdout, six);
 
-  printf ("\nmsix=\n");
-  bxprint (stdout, msix);
+  printf ("msix=\n");
+  xbprint (stdout, msix);
   canonic_form (&msix);
-  printf ("\nmsix=\n");
-  bxprint (stdout, msix);
+  printf ("msix=\n");
+  xbprint (stdout, msix);
 
-  printf ("\nseven=\n");
-  bxprint (stdout, seven);
+  printf ("seven=\n");
+  xbprint (stdout, seven);
   canonic_form (&seven);
-  printf ("\nseven=\n");
-  bxprint (stdout, seven);
+  printf ("seven=\n");
+  xbprint (stdout, seven);
 
-  printf ("\nmseven=\n");
-  bxprint (stdout, mseven);
+  printf ("mseven=\n");
+  xbprint (stdout, mseven);
   canonic_form (&mseven);
-  printf ("\nmseven=\n");
-  bxprint (stdout, mseven);
+  printf ("mseven=\n");
+  xbprint (stdout, mseven);
 
-  printf ("\neight=\n");
-  bxprint (stdout, eight);
+  printf ("eight=\n");
+  xbprint (stdout, eight);
   canonic_form (&eight);
-  printf ("\neight=\n");
-  bxprint (stdout, eight);
+  printf ("eight=\n");
+  xbprint (stdout, eight);
 
-  printf ("\nmeight=\n");
-  bxprint (stdout, meight);
+  printf ("meight=\n");
+  xbprint (stdout, meight);
   canonic_form (&meight);
-  printf ("\nmeight=\n");
-  bxprint (stdout, meight);
+  printf ("meight=\n");
+  xbprint (stdout, meight);
 
-  printf ("\none_two_seven=\n");
-  bxprint (stdout, one_two_seven);
+  printf ("one_two_seven=\n");
+  xbprint (stdout, one_two_seven);
   canonic_form (&one_two_seven);
-  printf ("\none_two_seven=\n");
-  bxprint (stdout, one_two_seven);
+  printf ("one_two_seven=\n");
+  xbprint (stdout, one_two_seven);
 
-  printf ("\nmone_two_seven=\n");
-  bxprint (stdout, mone_two_seven);
+  printf ("mone_two_seven=\n");
+  xbprint (stdout, mone_two_seven);
   canonic_form (&mone_two_seven);
-  printf ("\nmone_two_seven=\n");
-  bxprint (stdout, mone_two_seven);
+  printf ("mone_two_seven=\n");
+  xbprint (stdout, mone_two_seven);
 
-  printf ("\none_half=\n");
-  bxprint (stdout, one_half);
+  printf ("one_half=\n");
+  xbprint (stdout, one_half);
   canonic_form (&one_half);
-  printf ("\none_half=\n");
-  bxprint (stdout, one_half);
+  printf ("one_half=\n");
+  xbprint (stdout, one_half);
 
-  printf ("\n_1_=\n");
-  bxprint (stdout, _1_);
+  printf ("_1_=\n");
+  xbprint (stdout, _1_);
   canonic_form (&_1_);
-  printf ("\n_1_=\n");
-  bxprint (stdout, _1_);
+  printf ("_1_=\n");
+  xbprint (stdout, _1_);
 
-  printf ("\nalmost_seven=\n");
-  bxprint (stdout, almost_seven);
+  printf ("almost_seven=\n");
+  xbprint (stdout, almost_seven);
   canonic_form (&almost_seven);
-  printf ("\nalmost_seven=\n");
-  bxprint (stdout, almost_seven);
+  printf ("almost_seven=\n");
+  xbprint (stdout, almost_seven);
 
-  printf ("\nnear_seven=\n");
-  bxprint (stdout, near_seven);
+  printf ("near_seven=\n");
+  xbprint (stdout, near_seven);
   canonic_form (&near_seven);
-  printf ("\nnear_seven=\n");
-  bxprint (stdout, near_seven);
+  printf ("near_seven=\n");
+  xbprint (stdout, near_seven);
 
-  printf ("\nzero=\n");
-  bxprint (stdout, Zero);
+  printf ("zero=\n");
+  xbprint (stdout, Zero);
   canonic_form (&Zero);
-  printf ("\nZero=\n");
-  bxprint (stdout, Zero);
+  printf ("Zero=\n");
+  xbprint (stdout, Zero);
 
-  printf ("\nOne=\n");
-  bxprint (stdout, One);
+  printf ("One=\n");
+  xbprint (stdout, One);
   canonic_form (&One);
-  printf ("\nOne=\n");
-  bxprint (stdout, One);
-  putchar ('\n');
+  printf ("One=\n");
+  xbprint (stdout, One);
   return 0;
 }
 
