@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -32,18 +32,20 @@
 #include <stdlib.h>
 #include "cxpre.h"
 
-#define BUFF_SIZE 5120 /* 5 Kb */
-int decd=30;
+#define BUFF_SIZE 5120		/* 5 Kb */
+int decd = 30;
 
-void getflags (const char* buffer, struct xoutflags* pofs)
+void
+getflags (const char *buffer, struct xoutflags *pofs)
 {
-  sscanf (buffer, "%hi %hi %hi %hi %hi %c %c %c", &pofs->fmt, &pofs->notat, 
+  sscanf (buffer, "%hi %hi %hi %hi %hi %c %c %c", &pofs->fmt, &pofs->notat,
 	  &pofs->sf, &pofs->mfwd, &pofs->lim, &pofs->padding,
 	  &pofs->ldel, &pofs->rdel);
 }
 
-int main(int na,char **av)
-{ 
+int
+main (int na, char **av)
+{
   struct cxpr x;
   int i;
   char buffer[BUFF_SIZE];
@@ -51,22 +53,22 @@ int main(int na,char **av)
   unsigned long n;
   FILE *fp;
 
-  if(na!=2)
-    { 
-      printf("para: input_file\n"); 
-      exit(-1);
-    }
-  fp=fopen(*++av,"r");
-  printf("     Test of Special Printing Functions\n");
-  while( fgets(buffer, BUFF_SIZE, fp) != NULL )
+  if (na != 2)
     {
-      for (i=0; buffer[i] != '\0'; i++);
-      if ( i>0 && buffer[i-1] == '\n' )
-	buffer[i-1] = '\0';
+      printf ("para: input_file\n");
+      exit (-1);
+    }
+  fp = fopen (*++av, "r");
+  printf ("     Test of Special Printing Functions\n");
+  while (fgets (buffer, BUFF_SIZE, fp) != NULL)
+    {
+      for (i = 0; buffer[i] != '\0'; i++);
+      if (i > 0 && buffer[i - 1] == '\n')
+	buffer[i - 1] = '\0';
       if (buffer[0] == '*')
 	{
 	  getflags (buffer + 1, &ofs);
-	  printf ("* %hi %hi %hi %hi %hi %c %c %c\n", ofs.fmt, ofs.notat, 
+	  printf ("* %hi %hi %hi %hi %hi %c %c %c\n", ofs.fmt, ofs.notat,
 		  ofs.sf, ofs.mfwd, ofs.lim, ofs.padding, ofs.ldel, ofs.rdel);
 	}
       else
