@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -23,7 +23,7 @@
 /*
     Test:  cxpwr  cxroot
 
-    Uses:  cxpwr  cxroot  str2cx  print_cxpr
+    Uses:  cxpwr  cxroot  strtocx  xpr_asprint
 
     Input file:  data/cxpwr.dat
 */
@@ -33,14 +33,15 @@
 
 #define DECD 32
 
-int getline (char* buffer, int size, FILE* fp)
+int
+getline (char *buffer, int size, FILE * fp)
 {
-  if ( (fgets (buffer, size, fp)) )
+  if ((fgets (buffer, size, fp)))
     {
       int i;
 
-      for (i=0; buffer[i] != '\0'; i++);
-      if ( i > 0 && buffer[i-1] == '\n' )
+      for (i = 0; buffer[i] != '\0'; i++);
+      if (i > 0 && buffer[i - 1] == '\n')
 	buffer[--i] = '\0';
       return i;
     }
@@ -48,44 +49,47 @@ int getline (char* buffer, int size, FILE* fp)
     return -1;
 }
 
-extern int xerrno;
+extern int xErrNo;
 
-int main(int na,char **av)
-{ 
+int
+main (int na, char **av)
+{
   struct cxpr z, w;
   FILE *fp;
   char num[1024], *re, *im, *endptr;
   int n, i;
 
-  if(na!=2)
-    { 
-      printf("para: input_file\n");
-      exit(-1);
+  if (na != 2)
+    {
+      printf ("para: input_file\n");
+      exit (-1);
     }
-  fp=fopen(*++av,"r");
+  fp = fopen (*++av, "r");
   /* Test of cxpwr() */
   printf ("\nTest of cxpwr()\n");
-  while( getline(num, 1024, fp) != -1 )
+  while (getline (num, 1024, fp) != -1)
     {
-      printf("*string in : \t%s\n", num);
+      printf ("*string in : \t%s\n", num);
       /* convert ascii string to extended precision complex */
-      z= str2cx (num, &endptr);
-      re = asprint_xpr (z.re, 1, 0, DECD);
-      im = asprint_xpr (z.im, 1, 0, DECD);
-      printf(" z =  \t\t%s  \t%s\n", re, im); 
-      free ((void*)re); free ((void*)im);
+      z = strtocx (num, &endptr);
+      re = xpr_asprint (z.re, 1, 0, DECD);
+      im = xpr_asprint (z.im, 1, 0, DECD);
+      printf (" z =  \t\t%s  \t%s\n", re, im);
+      free ((void *) re);
+      free ((void *) im);
       n = atoi (endptr);
-      printf(" n = %d\n", n);
-      printf(" cxpwr(z,n) = \t");
-      xerrno = 0;
-      w = cxpwr(z, n);
-      switch (xerrno)
+      printf (" n = %d\n", n);
+      printf (" cxpwr(z,n) = \t");
+      xErrNo = 0;
+      w = cxpwr (z, n);
+      switch (xErrNo)
 	{
 	case XENONE:
-	  re = asprint_xpr (w.re, 1, 0, DECD);
-	  im = asprint_xpr (w.im, 1, 0, DECD);
-	  printf("%s  \t%s\n", re, im);
-	  free ((void*)re); free ((void*)im);
+	  re = xpr_asprint (w.re, 1, 0, DECD);
+	  im = xpr_asprint (w.im, 1, 0, DECD);
+	  printf ("%s  \t%s\n", re, im);
+	  free ((void *) re);
+	  free ((void *) im);
 	  break;
 	case XEDIV:
 	  printf ("*** Division by zero\n");
@@ -106,29 +110,31 @@ int main(int na,char **av)
   rewind (fp);
   /* Test of cxroot() */
   printf ("\nTest of cxroot()\n");
-  while( getline(num, 1024, fp) != -1 )
+  while (getline (num, 1024, fp) != -1)
     {
-      printf("*string in : \t%s\n", num);
+      printf ("*string in : \t%s\n", num);
       /* convert ascii string to extended precision complex */
-      z= str2cx (num, &endptr);
-      re = asprint_xpr (z.re, 1, 0, DECD);
-      im = asprint_xpr (z.im, 1, 0, DECD);
-      printf(" z =  \t\t%s  \t%s\n", re, im); 
-      free ((void*)re); free ((void*)im);
+      z = strtocx (num, &endptr);
+      re = xpr_asprint (z.re, 1, 0, DECD);
+      im = xpr_asprint (z.im, 1, 0, DECD);
+      printf (" z =  \t\t%s  \t%s\n", re, im);
+      free ((void *) re);
+      free ((void *) im);
       n = atoi (endptr);
-      printf(" n = %d\n", n);
-      for (i=0; i<= abs(n); i++)
+      printf (" n = %d\n", n);
+      for (i = 0; i <= abs (n); i++)
 	{
-	  printf(" cxroot(z,%d,n) = \t", i);
-	  xerrno = 0;
-	  w = cxroot(z, i, n);
-	  switch (xerrno)
+	  printf (" cxroot(z,%d,n) = \t", i);
+	  xErrNo = 0;
+	  w = cxroot (z, i, n);
+	  switch (xErrNo)
 	    {
 	    case XENONE:
-	      re = asprint_xpr (w.re, 1, 0, DECD);
-	      im = asprint_xpr (w.im, 1, 0, DECD);
-	      printf("%s  \t%s\n", re, im);
-	      free ((void*)re); free ((void*)im);
+	      re = xpr_asprint (w.re, 1, 0, DECD);
+	      im = xpr_asprint (w.im, 1, 0, DECD);
+	      printf ("%s  \t%s\n", re, im);
+	      free ((void *) re);
+	      free ((void *) im);
 	      break;
 	    case XEDIV:
 	      printf ("*** Division by zero\n");
