@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -21,9 +21,9 @@
 */
 
 /*
-    Test:  print_cxpr  cxprint  
+    Test:  cxpr_print  cxprint  
 
-    Uses:  print_cxpr  cxprint  xprint  atocx  
+    Uses:  cxpr_print  cxprint  xprint  atocx  
 
     Input file:  data/prcxpr.dat
 */
@@ -32,49 +32,66 @@
 #include <stdlib.h>
 #include "cxpre.h"
 
-#define BUFF_SIZE 5120 /* 5 Kb */
-int decd=30;
+#define BUFF_SIZE 5120		/* 5 Kb */
+int decd = 30;
 
-int main(int na,char **av)
-{ 
+int
+main (int na, char **av)
+{
   struct cxpr x;
   int i;
-  char buffer [BUFF_SIZE];
+  char buffer[BUFF_SIZE];
   FILE *fp;
 
-  if(na!=2)
-    { 
-      printf("para: input_file\n"); 
-      exit(-1);
-    }
-  fp=fopen(*++av,"r");
-  printf("     Test of Printing Functions\n");
-  while( fgets(buffer, BUFF_SIZE, fp) != NULL )
+  if (na != 2)
     {
-      for (i=0; buffer[i] != '\0'; i++);
-      if ( i>0 && buffer[i-1] == '\n' )
-	buffer[i-1] = '\0';
+      printf ("para: input_file\n");
+      exit (-1);
+    }
+  fp = fopen (*++av, "r");
+  printf ("     Test of Printing Functions\n");
+  while (fgets (buffer, BUFF_SIZE, fp) != NULL)
+    {
+      for (i = 0; buffer[i] != '\0'; i++);
+      if (i > 0 && buffer[i - 1] == '\n')
+	buffer[i - 1] = '\0';
       printf ("buffer : %s\n", buffer);
       x = atocx (buffer);
       cxprint (stdout, x);
       xprint (stdout, x.re);
       xprint (stdout, x.im);
-      print_cxpr (stdout, x, 0, 0, -1);
-      print_cxpr (stdout, x, 0, 0,  6);
-      print_cxpr (stdout, x, 0, 0,  decd);
-      print_cxpr (stdout, x, 0, 0,  160);
-      print_cxpr (stdout, x, 0, 1, -1);
-      print_cxpr (stdout, x, 0, 1,  6);
-      print_cxpr (stdout, x, 0, 1,  decd);
-      print_cxpr (stdout, x, 0, 1,  160);
-      print_cxpr (stdout, x, 1, 0, -1);
-      print_cxpr (stdout, x, 1, 0,  6);
-      print_cxpr (stdout, x, 1, 0,  decd);
-      print_cxpr (stdout, x, 1, 0,  160);
-      print_cxpr (stdout, x, 1, 1, -1);
-      print_cxpr (stdout, x, 1, 1,  6);
-      print_cxpr (stdout, x, 1, 1,  decd);
-      print_cxpr (stdout, x, 1, 1,  160);
+      cxpr_print (stdout, x, 0, 0, -1);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 0, 6);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 0, decd);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 0, 160);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 1, -1);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 1, 6);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 1, decd);
+      putchar ('\n');
+      cxpr_print (stdout, x, 0, 1, 160);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 0, -1);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 0, 6);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 0, decd);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 0, 160);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 1, -1);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 1, 6);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 1, decd);
+      putchar ('\n');
+      cxpr_print (stdout, x, 1, 1, 160);
+      putchar ('\n');
     }
   fclose (fp);
   return 0;
