@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -21,7 +21,7 @@
 */
 
 /*
-    Test:  str2cx  asprint_cxpr
+    Test:  strtocx  cxpr_asprint
 
     Input file:  data/str2cx.dat
 */
@@ -31,14 +31,25 @@
 
 #define DECD 30
 
-int getline (char* buffer, int size, FILE* fp)
+int
+isNaN (const struct cxpr* z)
 {
-  if ( (fgets (buffer, size, fp)) )
+  int i, j;
+
+  for (i=0; i <= XDIM && z->re.nmm[i] == xNaN.nmm[i]; i++);
+  for (j=0; j <= XDIM && z->im.nmm[j] == xNaN.nmm[j]; j++);
+  return (i > XDIM && j > XDIM ? 1 : 0);
+}
+
+int
+getline (char *buffer, int size, FILE * fp)
+{
+  if ((fgets (buffer, size, fp)))
     {
       int i;
 
-      for (i=0; buffer[i] != '\0'; i++);
-      if ( i > 0 && buffer[i-1] == '\n' )
+      for (i = 0; buffer[i] != '\0'; i++);
+      if (i > 0 && buffer[i - 1] == '\n')
 	buffer[--i] = '\0';
       return i;
     }
@@ -46,37 +57,39 @@ int getline (char* buffer, int size, FILE* fp)
     return -1;
 }
 
-int main(int na,char **av)
-{ 
+int
+main (int na, char **av)
+{
   struct cxpr z;
   FILE *fp;
   char num[256], *buffer;
   char *endptr;
 
-  if(na!=2)
-    { 
-      printf("para: input_file\n");
-      exit(-1);
-    }
-  fp=fopen(*++av,"r");
-  while( getline(num, 256, fp) != -1 )
+  if (na != 2)
     {
-      printf("*string in : \"%s\"\n", num);
+      printf ("para: input_file\n");
+      exit (-1);
+    }
+  fp = fopen (*++av, "r");
+  while (getline (num, 256, fp) != -1)
+    {
+      printf ("*string in : \"%s\"\n", num);
 
       /* convert ascii string to extended precision complex */
-      z=str2cx(num, &endptr);
+      z = strtocx (num, &endptr);
       printf (" endptr   : \"%s\"\n", endptr);
-      if ( endptr == num )
+      if ((isNaN(&z)))
 	printf (" NAN\n");
-      else if ( xprcmp( &z.re, &x_huge ) == 0 ||  xprcmp( &z.im, &x_huge ) == 0)
+      else if (xprcmp (&z.re, &xPinf) == 0 || xprcmp (&z.im, &xPinf) == 0 ||
+	       xprcmp (&z.re, &xMinf) == 0 || xprcmp (&z.im, &xMinf) == 0)
 	printf (" OVERFLOW\n");
       else
 	{
-	  printf(" z =       "); 
-	  if ( (buffer = asprint_cxpr (z, 1, 1, DECD)) )
+	  printf (" z =       ");
+	  if ((buffer = cxpr_asprint (z, 1, 1, DECD)))
 	    {
 	      printf ("%s\n", buffer);
-	      free ((void*) buffer);
+	      free ((void *) buffer);
 	    }
 	  else
 	    printf ("*** Out of memory\n");
