@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -21,57 +21,71 @@
 */
 
 /*
-    Test:  neg  xex  xabs  xneg  xpr2
+    Test:  x_neg  x_exp  xabs  xneg  xpr2
 
-    Uses:  atox  prxpr
+    Uses:  atox  xprxpr
 
     Input parameter:  x -> extended precision: test number
 */
 #include <stdio.h>
 #include "xpre.h"
 
-int decd=30;
+int decd = 30;
 
-int main(int na,char **av)
-{ 
-  struct xpr s,t; int k;
-  
-  if(na!=2)
-    { printf("para: test_num\n"); exit(-1);}
-  printf("     Test of Utility Operations\n");
-  s=atox(*++av);
-  printf("   input x= "); prxpr(s,decd);
+int
+main (int na, char **av)
+{
+  struct xpr s, t;
+  int k;
+
+  if (na != 2)
+    {
+      printf ("para: test_num\n");
+      exit (-1);
+    }
+  printf ("     Test of Utility Operations\n");
+  s = atox (*++av);
+  printf ("   input x= ");
+  xprxpr (s, decd);
 
   /* t= -s */
-  t=xneg(s);
-  printf(" t=xneg(x)= "); prxpr(t,decd);
+  t = xneg (s);
+  printf ("\n t=xneg(x)= ");
+  xprxpr (t, decd);
 
   /* s -> -s */
-  neg(&s);
-  printf("   neg(x) = "); prxpr(s,decd);
+  x_neg (&s);
+  printf ("\n x_neg(x) = ");
+  xprxpr (s, decd);
 
   /* extract exponent */
-  k=xex(&s); printf(" x-exp= k = %d\n",k);
-  s=xpr2(s,-k);
-  printf("      <s> = "); prxpr(s,decd);
+  k = x_exp (&s);
+  printf ("\n x-exp= k = %d\n", k);
+  s = xpr2 (s, -k);
+  printf ("      <s> = ");
+  xprxpr (s, decd);
 
   /* restore exponent */
-  s=xpr2(s,k);
-  printf("  <s>*2^k = "); prxpr(s,decd);
+  s = xpr2 (s, k);
+  printf ("\n  <s>*2^k = ");
+  xprxpr (s, decd);
 
   /* s -> |s| */
-  t=xabs(s);
-  printf(" t=abs(s) = "); prxpr(t,decd);
+  t = xabs (s);
+  printf ("\n t=abs(s) = ");
+  xprxpr (t, decd);
+  putchar ('\n');
   return 0;
 }
+
 /*  Test output
 
      Test of Utility Operations
-   input x=  -1.240000000000000000000000000000e-3
- t=xneg(x)=   1.240000000000000000000000000000e-3
-   neg(x) =  -1.240000000000000000000000000000e-3
+   input x= -1.240000000000000000000000000000e-3
+ t=xneg(x)= 1.240000000000000000000000000000e-3
+ x_neg(x) = -1.240000000000000000000000000000e-3
  x-exp= k = -10
-      <s> =  -1.269760000000000000000000000000e+0
-  <s>*2^k =  -1.240000000000000000000000000000e-3
- t=abs(s) =   1.240000000000000000000000000000e-3
+      <s> = -1.269760000000000000000000000000e+0
+  <s>*2^k = -1.240000000000000000000000000000e-3
+ t=abs(s) = 1.240000000000000000000000000000e-3
 */
