@@ -1,5 +1,5 @@
 /*
-   Copyright (C)  2000    Daniel A. Atkinson
+   Copyright (C)  2000    Daniel A. Atkinson  <DanAtk@aol.com>
    Copyright (C)  2004    Ivano Primi  <ivano.primi@tin.it>    
 
    This file is part of the HPA Library.
@@ -21,9 +21,9 @@
 */
 
 /*
-    Test:  xfmod  xfrex  xpr2
+    Test:  xfmod  xfrexp  xpr2
 
-    Uses:  atox  prxpr
+    Uses:  atox  xprxpr
 
     Input parameters:  x -> extended precision: first argument
                        y -> extended precision: second argument
@@ -31,44 +31,59 @@
 #include <stdio.h>
 #include "xpre.h"
 
-int decd=30;
+int decd = 30;
 
-int main (int na,char **av)
-{ 
-  struct xpr s, t, f, q; 
+int
+main (int na, char **av)
+{
+  struct xpr s, t, f, q;
   int k;
-  
-  if(na!=3) { printf("para: x y\n"); exit(-1);}
-  printf("     Test of FMOD functions\n");
-  s=atox(*++av); t=atox(*++av);
-  printf(" inputs:\n");
-  printf(" s="); prxpr(s,decd);
-  printf(" t="); prxpr(t,decd);
+
+  if (na != 3)
+    {
+      printf ("para: x y\n");
+      exit (-1);
+    }
+  printf ("     Test of FMOD functions\n");
+  s = atox (*++av);
+  t = atox (*++av);
+  printf (" inputs:\n");
+  printf (" s=  ");
+  xprxpr (s, decd);
+  printf ("\n t=  ");
+  xprxpr (t, decd);
 
   /* extended precision modular divide */
-  f=xfmod(s,t,&q);
-  printf(" s mod t = "); prxpr(f,decd);
-  printf("       q = "); prxpr(q,decd);
-  printf("\n s="); prxpr(s,decd);
+  f = xfmod (s, t, &q);
+  printf ("\n s mod t = ");
+  xprxpr (f, decd);
+  printf ("\n       q = ");
+  xprxpr (q, decd);
+  printf ("\n\n s=  ");
+  xprxpr (s, decd);
 
   /* extended precision exponent extraction */
-  s=xfrex(s,&k);
-  printf(" exp= %d\n",k);
-  printf(" <s>="); prxpr(s,decd);
+  s = xfrexp (s, &k);
+  printf ("\n exp= %d\n", k);
+  printf (" <s>=  ");
+  xprxpr (s, decd);
 
   /* extended precision power of two */
-  s=xpr2(s,k);
-  printf("   s="); prxpr(s,decd);
+  s = xpr2 (s, k);
+  printf ("\n   s=  ");
+  xprxpr (s, decd);
+  putchar ('\n');
   return 0;
 }
+
 /*  Test output
 
      Test of FMOD functions
  inputs:
  s=  1.250000000000000000000000000000e+1
  t=  3.000000000000000000000000000000e+0
- s mod t =   5.000000000000000000000000000000e-1
-       q =   4.000000000000000000000000000000e+0
+ s mod t = 5.000000000000000000000000000000e-1
+       q = 4.000000000000000000000000000000e+0
 
  s=  1.250000000000000000000000000000e+1
  exp= 4
